# Chore Models

Classes for representing chores and their scheduling configuration.

## Chore

::: grocy.data_models.chore.Chore
    options:
      members_order: source

## PeriodType

Scheduling period types for chores.

::: grocy.data_models.chore.PeriodType
    options:
      members_order: source

## AssignmentType

How chores are assigned to users.

::: grocy.data_models.chore.AssignmentType
    options:
      members_order: source
